"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Envelope = void 0;
const errors_js_1 = require("../errors.js");
class Envelope {
}
exports.Envelope = Envelope;
/**
 * Abstract function to parse the content of the envelope using provided schema.
 * Both inputs are provided as unknown by the user.
 * We expect the data to be either string that can be parsed to json or object.
 * @internal
 * @param data data to parse
 * @param schema schema
 */
Envelope.parse = (data, schema) => {
    if (typeof data !== 'object' && typeof data !== 'string') {
        throw new errors_js_1.ParseError(`Invalid data type for envelope. Expected string or object, got ${typeof data}`);
    }
    try {
        if (typeof data === 'string') {
            return schema.parse(JSON.parse(data));
        }
        else if (typeof data === 'object') {
            return schema.parse(data);
        }
    }
    catch (e) {
        throw new errors_js_1.ParseError(`Failed to parse envelope`, e);
    }
};
/**
 * Abstract function to safely parse the content of the envelope using provided schema.
 * safeParse is used to avoid throwing errors, thus we catuch all errors and wrap them in the result.
 * @param input
 * @param schema
 */
Envelope.safeParse = (input, schema) => {
    try {
        if (typeof input !== 'object' && typeof input !== 'string') {
            return {
                success: false,
                error: new errors_js_1.ParseError(`Invalid data type for envelope. Expected string or object, got ${typeof input}`),
                originalEvent: input,
            };
        }
        const parsed = schema.safeParse(typeof input === 'string' ? JSON.parse(input) : input);
        return parsed.success
            ? {
                success: true,
                data: parsed.data,
            }
            : {
                success: false,
                error: new errors_js_1.ParseError(`Failed to parse envelope`, parsed.error),
                originalEvent: input,
            };
    }
    catch (e) {
        return {
            success: false,
            error: new errors_js_1.ParseError(`Failed to parse envelope`, e),
            originalEvent: input,
        };
    }
};
