"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIGatewayProxyEventV2Schema = void 0;
const zod_1 = require("zod");
const apigw_js_1 = require("./apigw.js");
const RequestContextV2Authorizer = zod_1.z.object({
    jwt: zod_1.z
        .object({
        claims: zod_1.z.record(zod_1.z.string(), zod_1.z.any()),
        scopes: zod_1.z.array(zod_1.z.string()).optional(),
    })
        .optional(),
    iam: zod_1.z
        .object({
        accessKey: zod_1.z.string().optional(),
        accountId: zod_1.z.string().optional(),
        callerId: zod_1.z.string().optional(),
        principalOrgId: zod_1.z.string().nullish(),
        userArn: zod_1.z.string().optional(),
        userId: zod_1.z.string().optional(),
        cognitoIdentity: zod_1.z
            .object({
            amr: zod_1.z.array(zod_1.z.string()),
            identityId: zod_1.z.string(),
            identityPoolId: zod_1.z.string(),
        })
            .nullish(),
    })
        .optional(),
    lambda: zod_1.z.record(zod_1.z.string(), zod_1.z.any()).optional(),
});
const RequestContextV2Http = zod_1.z.object({
    method: zod_1.z.enum(['GET', 'POST', 'PUT', 'PATCH', 'DELETE', 'HEAD', 'OPTIONS']),
    path: zod_1.z.string(),
    protocol: zod_1.z.string(),
    sourceIp: zod_1.z.string().ip(),
    userAgent: zod_1.z.string(),
});
const RequestContextV2 = zod_1.z.object({
    accountId: zod_1.z.string(),
    apiId: zod_1.z.string(),
    authorizer: RequestContextV2Authorizer.optional(),
    authentication: zod_1.z
        .object({
        clientCert: apigw_js_1.APIGatewayCert.optional(),
    })
        .nullish(),
    domainName: zod_1.z.string(),
    domainPrefix: zod_1.z.string(),
    http: RequestContextV2Http,
    requestId: zod_1.z.string(),
    routeKey: zod_1.z.string(),
    stage: zod_1.z.string(),
    time: zod_1.z.string(),
    timeEpoch: zod_1.z.number(),
});
const APIGatewayProxyEventV2Schema = zod_1.z.object({
    version: zod_1.z.string(),
    routeKey: zod_1.z.string(),
    rawPath: zod_1.z.string(),
    rawQueryString: zod_1.z.string(),
    cookies: zod_1.z.array(zod_1.z.string()).optional(),
    headers: zod_1.z.record(zod_1.z.string()),
    queryStringParameters: zod_1.z.record(zod_1.z.string()).optional(),
    pathParameters: zod_1.z.record(zod_1.z.string()).optional().nullish(),
    stageVariables: zod_1.z.record(zod_1.z.string()).optional().nullish(),
    requestContext: RequestContextV2,
    body: zod_1.z.string().optional(),
    isBase64Encoded: zod_1.z.boolean(),
});
exports.APIGatewayProxyEventV2Schema = APIGatewayProxyEventV2Schema;
