"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KinesisDataStreamRecordPayload = exports.KinesisDataStreamRecord = exports.KinesisDataStreamSchema = void 0;
const zod_1 = require("zod");
const node_zlib_1 = require("node:zlib");
const KinesisDataStreamRecordPayload = zod_1.z.object({
    kinesisSchemaVersion: zod_1.z.string(),
    partitionKey: zod_1.z.string(),
    sequenceNumber: zod_1.z.string(),
    approximateArrivalTimestamp: zod_1.z.number(),
    data: zod_1.z.string().transform((data) => {
        const decompresed = decompress(data);
        const decoded = Buffer.from(data, 'base64').toString('utf-8');
        try {
            // If data was not compressed, try to parse it as JSON otherwise it must be string
            return decompresed === data ? JSON.parse(decoded) : decompresed;
        }
        catch (e) {
            return decoded;
        }
    }),
});
exports.KinesisDataStreamRecordPayload = KinesisDataStreamRecordPayload;
const decompress = (data) => {
    try {
        return JSON.parse((0, node_zlib_1.gunzipSync)(Buffer.from(data, 'base64')).toString('utf8'));
    }
    catch (e) {
        return data;
    }
};
const KinesisDataStreamRecord = zod_1.z.object({
    eventSource: zod_1.z.literal('aws:kinesis'),
    eventVersion: zod_1.z.string(),
    eventID: zod_1.z.string(),
    eventName: zod_1.z.literal('aws:kinesis:record'),
    invokeIdentityArn: zod_1.z.string(),
    eventSourceARN: zod_1.z.string(),
    kinesis: KinesisDataStreamRecordPayload,
});
exports.KinesisDataStreamRecord = KinesisDataStreamRecord;
const KinesisDataStreamSchema = zod_1.z.object({
    Records: zod_1.z.array(KinesisDataStreamRecord),
});
exports.KinesisDataStreamSchema = KinesisDataStreamSchema;
