/**
 * Lambda Function URL follows the API Gateway HTTP APIs Payload Format Version 2.0.
 *
 * Keys related to API Gateway features not available in Function URL use a sentinel value (e.g.`routeKey`, `stage`).
 * Documentation:
 * - https://docs.aws.amazon.com/lambda/latest/dg/urls-configuration.html
 * - https://docs.aws.amazon.com/lambda/latest/dg/urls-invocation.html#urls-payloads
 *
 */
declare const LambdaFunctionUrlSchema: import("zod").ZodObject<import("zod").objectUtil.extendShape<{
    version: import("zod").ZodString;
    routeKey: import("zod").ZodString;
    rawPath: import("zod").ZodString;
    rawQueryString: import("zod").ZodString;
    cookies: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
    headers: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>;
    queryStringParameters: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
    pathParameters: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>>;
    stageVariables: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>>;
    requestContext: import("zod").ZodObject<{
        accountId: import("zod").ZodString;
        apiId: import("zod").ZodString;
        authorizer: import("zod").ZodOptional<import("zod").ZodObject<{
            jwt: import("zod").ZodOptional<import("zod").ZodObject<{
                claims: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodAny>;
                scopes: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
            }, "strip", import("zod").ZodTypeAny, {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            }, {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            }>>;
            iam: import("zod").ZodOptional<import("zod").ZodObject<{
                accessKey: import("zod").ZodOptional<import("zod").ZodString>;
                accountId: import("zod").ZodOptional<import("zod").ZodString>;
                callerId: import("zod").ZodOptional<import("zod").ZodString>;
                principalOrgId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                userArn: import("zod").ZodOptional<import("zod").ZodString>;
                userId: import("zod").ZodOptional<import("zod").ZodString>;
                cognitoIdentity: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                    amr: import("zod").ZodArray<import("zod").ZodString, "many">;
                    identityId: import("zod").ZodString;
                    identityPoolId: import("zod").ZodString;
                }, "strip", import("zod").ZodTypeAny, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }>>>;
            }, "strip", import("zod").ZodTypeAny, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }>>;
            lambda: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodAny>>;
        }, "strip", import("zod").ZodTypeAny, {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        }, {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        }>>;
        authentication: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
            clientCert: import("zod").ZodOptional<import("zod").ZodObject<{
                clientCertPem: import("zod").ZodString;
                subjectDN: import("zod").ZodString;
                issuerDN: import("zod").ZodString;
                serialNumber: import("zod").ZodString;
                validity: import("zod").ZodObject<{
                    notBefore: import("zod").ZodString;
                    notAfter: import("zod").ZodString;
                }, "strip", import("zod").ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", import("zod").ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>;
        }, "strip", import("zod").ZodTypeAny, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }>>>;
        domainName: import("zod").ZodString;
        domainPrefix: import("zod").ZodString;
        http: import("zod").ZodObject<{
            method: import("zod").ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
            path: import("zod").ZodString;
            protocol: import("zod").ZodString;
            sourceIp: import("zod").ZodString;
            userAgent: import("zod").ZodString;
        }, "strip", import("zod").ZodTypeAny, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }>;
        requestId: import("zod").ZodString;
        routeKey: import("zod").ZodString;
        stage: import("zod").ZodString;
        time: import("zod").ZodString;
        timeEpoch: import("zod").ZodNumber;
    }, "strip", import("zod").ZodTypeAny, {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }, {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }>;
    body: import("zod").ZodOptional<import("zod").ZodString>;
    isBase64Encoded: import("zod").ZodBoolean;
}, {}>, "strip", import("zod").ZodTypeAny, {
    routeKey: string;
    version: string;
    headers: Record<string, string>;
    requestContext: {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    isBase64Encoded: boolean;
    rawPath: string;
    rawQueryString: string;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    body?: string | undefined;
    cookies?: string[] | undefined;
}, {
    routeKey: string;
    version: string;
    headers: Record<string, string>;
    requestContext: {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    isBase64Encoded: boolean;
    rawPath: string;
    rawQueryString: string;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    body?: string | undefined;
    cookies?: string[] | undefined;
}>;
export { LambdaFunctionUrlSchema };
//# sourceMappingURL=lambda.d.ts.map