import { z } from 'zod';
declare const SesRecordSchema: z.ZodObject<{
    eventSource: z.ZodLiteral<"aws:ses">;
    eventVersion: z.ZodString;
    ses: z.ZodObject<{
        mail: z.ZodObject<{
            timestamp: z.ZodString;
            source: z.ZodString;
            messageId: z.ZodString;
            destination: z.ZodArray<z.ZodString, "many">;
            headersTruncated: z.ZodBoolean;
            headers: z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                value: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string;
                name: string;
            }, {
                value: string;
                name: string;
            }>, "many">;
            commonHeaders: z.ZodObject<{
                from: z.ZodArray<z.ZodString, "many">;
                to: z.ZodArray<z.ZodString, "many">;
                cc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                bcc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                sender: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                'reply-to': z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                returnPath: z.ZodString;
                messageId: z.ZodString;
                date: z.ZodString;
                subject: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            }, {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            messageId: string;
            headers: {
                value: string;
                name: string;
            }[];
            timestamp: string;
            source: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        }, {
            messageId: string;
            headers: {
                value: string;
                name: string;
            }[];
            timestamp: string;
            source: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        }>;
        receipt: z.ZodObject<{
            timestamp: z.ZodString;
            processingTimeMillis: z.ZodNumber;
            recipients: z.ZodArray<z.ZodString, "many">;
            spamVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            virusVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            spfVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            dmarcVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            dkimVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            dmarcPolicy: z.ZodEnum<["none", "quarantine", "reject"]>;
            action: z.ZodObject<{
                type: z.ZodEnum<["Lambda"]>;
                invocationType: z.ZodLiteral<"Event">;
                functionArn: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            }, {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        }, {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        }>;
    }, "strip", z.ZodTypeAny, {
        mail: {
            messageId: string;
            headers: {
                value: string;
                name: string;
            }[];
            timestamp: string;
            source: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    }, {
        mail: {
            messageId: string;
            headers: {
                value: string;
                name: string;
            }[];
            timestamp: string;
            source: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    }>;
}, "strip", z.ZodTypeAny, {
    eventVersion: string;
    eventSource: "aws:ses";
    ses: {
        mail: {
            messageId: string;
            headers: {
                value: string;
                name: string;
            }[];
            timestamp: string;
            source: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    };
}, {
    eventVersion: string;
    eventSource: "aws:ses";
    ses: {
        mail: {
            messageId: string;
            headers: {
                value: string;
                name: string;
            }[];
            timestamp: string;
            source: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    };
}>;
declare const SesSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<{
        eventSource: z.ZodLiteral<"aws:ses">;
        eventVersion: z.ZodString;
        ses: z.ZodObject<{
            mail: z.ZodObject<{
                timestamp: z.ZodString;
                source: z.ZodString;
                messageId: z.ZodString;
                destination: z.ZodArray<z.ZodString, "many">;
                headersTruncated: z.ZodBoolean;
                headers: z.ZodArray<z.ZodObject<{
                    name: z.ZodString;
                    value: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string;
                    name: string;
                }, {
                    value: string;
                    name: string;
                }>, "many">;
                commonHeaders: z.ZodObject<{
                    from: z.ZodArray<z.ZodString, "many">;
                    to: z.ZodArray<z.ZodString, "many">;
                    cc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    bcc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    sender: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    'reply-to': z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    returnPath: z.ZodString;
                    messageId: z.ZodString;
                    date: z.ZodString;
                    subject: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                }, {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            }, {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            }>;
            receipt: z.ZodObject<{
                timestamp: z.ZodString;
                processingTimeMillis: z.ZodNumber;
                recipients: z.ZodArray<z.ZodString, "many">;
                spamVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                virusVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                spfVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                dmarcVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                dkimVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                dmarcPolicy: z.ZodEnum<["none", "quarantine", "reject"]>;
                action: z.ZodObject<{
                    type: z.ZodEnum<["Lambda"]>;
                    invocationType: z.ZodLiteral<"Event">;
                    functionArn: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                }, {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            }, {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            }>;
        }, "strip", z.ZodTypeAny, {
            mail: {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        }, {
            mail: {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        }>;
    }, "strip", z.ZodTypeAny, {
        eventVersion: string;
        eventSource: "aws:ses";
        ses: {
            mail: {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }, {
        eventVersion: string;
        eventSource: "aws:ses";
        ses: {
            mail: {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        eventVersion: string;
        eventSource: "aws:ses";
        ses: {
            mail: {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }[];
}, {
    Records: {
        eventVersion: string;
        eventSource: "aws:ses";
        ses: {
            mail: {
                messageId: string;
                headers: {
                    value: string;
                    name: string;
                }[];
                timestamp: string;
                source: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }[];
}>;
export { SesSchema, SesRecordSchema };
//# sourceMappingURL=ses.d.ts.map