"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SesRecordSchema = exports.SesSchema = void 0;
const zod_1 = require("zod");
const SesReceiptVerdict = zod_1.z.object({
    status: zod_1.z.enum(['PASS', 'FAIL', 'GRAY', 'PROCESSING_FAILED']),
});
const SesReceipt = zod_1.z.object({
    timestamp: zod_1.z.string().datetime(),
    processingTimeMillis: zod_1.z.number().int().positive(),
    recipients: zod_1.z.array(zod_1.z.string()),
    spamVerdict: SesReceiptVerdict,
    virusVerdict: SesReceiptVerdict,
    spfVerdict: SesReceiptVerdict,
    dmarcVerdict: SesReceiptVerdict,
    dkimVerdict: SesReceiptVerdict,
    dmarcPolicy: zod_1.z.enum(['none', 'quarantine', 'reject']),
    action: zod_1.z.object({
        type: zod_1.z.enum(['Lambda']),
        invocationType: zod_1.z.literal('Event'),
        functionArn: zod_1.z.string(),
    }),
});
const SesMail = zod_1.z.object({
    timestamp: zod_1.z.string().datetime(),
    source: zod_1.z.string(),
    messageId: zod_1.z.string(),
    destination: zod_1.z.array(zod_1.z.string()),
    headersTruncated: zod_1.z.boolean(),
    headers: zod_1.z.array(zod_1.z.object({
        name: zod_1.z.string(),
        value: zod_1.z.string(),
    })),
    commonHeaders: zod_1.z.object({
        from: zod_1.z.array(zod_1.z.string()),
        to: zod_1.z.array(zod_1.z.string()),
        cc: zod_1.z.array(zod_1.z.string()).optional(),
        bcc: zod_1.z.array(zod_1.z.string()).optional(),
        sender: zod_1.z.array(zod_1.z.string()).optional(),
        'reply-to': zod_1.z.array(zod_1.z.string()).optional(),
        returnPath: zod_1.z.string(),
        messageId: zod_1.z.string(),
        date: zod_1.z.string(),
        subject: zod_1.z.string(),
    }),
});
const SesMessage = zod_1.z.object({
    mail: SesMail,
    receipt: SesReceipt,
});
const SesRecordSchema = zod_1.z.object({
    eventSource: zod_1.z.literal('aws:ses'),
    eventVersion: zod_1.z.string(),
    ses: SesMessage,
});
exports.SesRecordSchema = SesRecordSchema;
const SesSchema = zod_1.z.object({
    Records: zod_1.z.array(SesRecordSchema),
});
exports.SesSchema = SesSchema;
