import { Envelope } from './envelope.js';
import { APIGatewayProxyEventSchema } from '../schemas/apigw.js';
import { ParseError } from '../errors.js';
/**
 * API Gateway envelope to extract data within body key
 */
export class ApiGatewayEnvelope extends Envelope {
    static parse(data, schema) {
        return super.parse(APIGatewayProxyEventSchema.parse(data).body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = APIGatewayProxyEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse ApiGatewayEnvelope', parsedEnvelope.error),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse ApiGatewayEnvelope body', parsedBody.error),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
