import { z } from 'zod';
declare const SqsMsgAttributeSchema: z.ZodObject<{
    stringValue: z.ZodOptional<z.ZodString>;
    binaryValue: z.ZodOptional<z.ZodString>;
    stringListValues: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    binaryListValues: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    dataType: z.ZodString;
}, "strip", z.ZodTypeAny, {
    dataType: string;
    stringValue?: string | undefined;
    binaryValue?: string | undefined;
    stringListValues?: string[] | undefined;
    binaryListValues?: string[] | undefined;
}, {
    dataType: string;
    stringValue?: string | undefined;
    binaryValue?: string | undefined;
    stringListValues?: string[] | undefined;
    binaryListValues?: string[] | undefined;
}>;
declare const SqsAttributesSchema: z.ZodObject<{
    ApproximateReceiveCount: z.ZodString;
    ApproximateFirstReceiveTimestamp: z.ZodString;
    MessageDeduplicationId: z.ZodOptional<z.ZodString>;
    MessageGroupId: z.ZodOptional<z.ZodString>;
    SenderId: z.ZodString;
    SentTimestamp: z.ZodString;
    SequenceNumber: z.ZodOptional<z.ZodString>;
    AWSTraceHeader: z.ZodOptional<z.ZodString>;
    /**
     * Undocumented, but used by AWS to support their re-drive functionality in the console
     */
    DeadLetterQueueSourceArn: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    ApproximateReceiveCount: string;
    ApproximateFirstReceiveTimestamp: string;
    SenderId: string;
    SentTimestamp: string;
    SequenceNumber?: string | undefined;
    MessageDeduplicationId?: string | undefined;
    MessageGroupId?: string | undefined;
    AWSTraceHeader?: string | undefined;
    DeadLetterQueueSourceArn?: string | undefined;
}, {
    ApproximateReceiveCount: string;
    ApproximateFirstReceiveTimestamp: string;
    SenderId: string;
    SentTimestamp: string;
    SequenceNumber?: string | undefined;
    MessageDeduplicationId?: string | undefined;
    MessageGroupId?: string | undefined;
    AWSTraceHeader?: string | undefined;
    DeadLetterQueueSourceArn?: string | undefined;
}>;
declare const SqsRecordSchema: z.ZodObject<{
    messageId: z.ZodString;
    receiptHandle: z.ZodString;
    body: z.ZodString;
    attributes: z.ZodObject<{
        ApproximateReceiveCount: z.ZodString;
        ApproximateFirstReceiveTimestamp: z.ZodString;
        MessageDeduplicationId: z.ZodOptional<z.ZodString>;
        MessageGroupId: z.ZodOptional<z.ZodString>;
        SenderId: z.ZodString;
        SentTimestamp: z.ZodString;
        SequenceNumber: z.ZodOptional<z.ZodString>;
        AWSTraceHeader: z.ZodOptional<z.ZodString>;
        /**
         * Undocumented, but used by AWS to support their re-drive functionality in the console
         */
        DeadLetterQueueSourceArn: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        ApproximateReceiveCount: string;
        ApproximateFirstReceiveTimestamp: string;
        SenderId: string;
        SentTimestamp: string;
        SequenceNumber?: string | undefined;
        MessageDeduplicationId?: string | undefined;
        MessageGroupId?: string | undefined;
        AWSTraceHeader?: string | undefined;
        DeadLetterQueueSourceArn?: string | undefined;
    }, {
        ApproximateReceiveCount: string;
        ApproximateFirstReceiveTimestamp: string;
        SenderId: string;
        SentTimestamp: string;
        SequenceNumber?: string | undefined;
        MessageDeduplicationId?: string | undefined;
        MessageGroupId?: string | undefined;
        AWSTraceHeader?: string | undefined;
        DeadLetterQueueSourceArn?: string | undefined;
    }>;
    messageAttributes: z.ZodRecord<z.ZodString, z.ZodObject<{
        stringValue: z.ZodOptional<z.ZodString>;
        binaryValue: z.ZodOptional<z.ZodString>;
        stringListValues: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        binaryListValues: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        dataType: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        dataType: string;
        stringValue?: string | undefined;
        binaryValue?: string | undefined;
        stringListValues?: string[] | undefined;
        binaryListValues?: string[] | undefined;
    }, {
        dataType: string;
        stringValue?: string | undefined;
        binaryValue?: string | undefined;
        stringListValues?: string[] | undefined;
        binaryListValues?: string[] | undefined;
    }>>;
    md5OfBody: z.ZodString;
    md5OfMessageAttributes: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    eventSource: z.ZodLiteral<"aws:sqs">;
    eventSourceARN: z.ZodString;
    awsRegion: z.ZodString;
}, "strip", z.ZodTypeAny, {
    messageId: string;
    body: string;
    eventSource: "aws:sqs";
    awsRegion: string;
    eventSourceARN: string;
    receiptHandle: string;
    attributes: {
        ApproximateReceiveCount: string;
        ApproximateFirstReceiveTimestamp: string;
        SenderId: string;
        SentTimestamp: string;
        SequenceNumber?: string | undefined;
        MessageDeduplicationId?: string | undefined;
        MessageGroupId?: string | undefined;
        AWSTraceHeader?: string | undefined;
        DeadLetterQueueSourceArn?: string | undefined;
    };
    messageAttributes: Record<string, {
        dataType: string;
        stringValue?: string | undefined;
        binaryValue?: string | undefined;
        stringListValues?: string[] | undefined;
        binaryListValues?: string[] | undefined;
    }>;
    md5OfBody: string;
    md5OfMessageAttributes?: string | null | undefined;
}, {
    messageId: string;
    body: string;
    eventSource: "aws:sqs";
    awsRegion: string;
    eventSourceARN: string;
    receiptHandle: string;
    attributes: {
        ApproximateReceiveCount: string;
        ApproximateFirstReceiveTimestamp: string;
        SenderId: string;
        SentTimestamp: string;
        SequenceNumber?: string | undefined;
        MessageDeduplicationId?: string | undefined;
        MessageGroupId?: string | undefined;
        AWSTraceHeader?: string | undefined;
        DeadLetterQueueSourceArn?: string | undefined;
    };
    messageAttributes: Record<string, {
        dataType: string;
        stringValue?: string | undefined;
        binaryValue?: string | undefined;
        stringListValues?: string[] | undefined;
        binaryListValues?: string[] | undefined;
    }>;
    md5OfBody: string;
    md5OfMessageAttributes?: string | null | undefined;
}>;
declare const SqsSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<{
        messageId: z.ZodString;
        receiptHandle: z.ZodString;
        body: z.ZodString;
        attributes: z.ZodObject<{
            ApproximateReceiveCount: z.ZodString;
            ApproximateFirstReceiveTimestamp: z.ZodString;
            MessageDeduplicationId: z.ZodOptional<z.ZodString>;
            MessageGroupId: z.ZodOptional<z.ZodString>;
            SenderId: z.ZodString;
            SentTimestamp: z.ZodString;
            SequenceNumber: z.ZodOptional<z.ZodString>;
            AWSTraceHeader: z.ZodOptional<z.ZodString>;
            /**
             * Undocumented, but used by AWS to support their re-drive functionality in the console
             */
            DeadLetterQueueSourceArn: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            ApproximateReceiveCount: string;
            ApproximateFirstReceiveTimestamp: string;
            SenderId: string;
            SentTimestamp: string;
            SequenceNumber?: string | undefined;
            MessageDeduplicationId?: string | undefined;
            MessageGroupId?: string | undefined;
            AWSTraceHeader?: string | undefined;
            DeadLetterQueueSourceArn?: string | undefined;
        }, {
            ApproximateReceiveCount: string;
            ApproximateFirstReceiveTimestamp: string;
            SenderId: string;
            SentTimestamp: string;
            SequenceNumber?: string | undefined;
            MessageDeduplicationId?: string | undefined;
            MessageGroupId?: string | undefined;
            AWSTraceHeader?: string | undefined;
            DeadLetterQueueSourceArn?: string | undefined;
        }>;
        messageAttributes: z.ZodRecord<z.ZodString, z.ZodObject<{
            stringValue: z.ZodOptional<z.ZodString>;
            binaryValue: z.ZodOptional<z.ZodString>;
            stringListValues: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            binaryListValues: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            dataType: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            dataType: string;
            stringValue?: string | undefined;
            binaryValue?: string | undefined;
            stringListValues?: string[] | undefined;
            binaryListValues?: string[] | undefined;
        }, {
            dataType: string;
            stringValue?: string | undefined;
            binaryValue?: string | undefined;
            stringListValues?: string[] | undefined;
            binaryListValues?: string[] | undefined;
        }>>;
        md5OfBody: z.ZodString;
        md5OfMessageAttributes: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        eventSource: z.ZodLiteral<"aws:sqs">;
        eventSourceARN: z.ZodString;
        awsRegion: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        messageId: string;
        body: string;
        eventSource: "aws:sqs";
        awsRegion: string;
        eventSourceARN: string;
        receiptHandle: string;
        attributes: {
            ApproximateReceiveCount: string;
            ApproximateFirstReceiveTimestamp: string;
            SenderId: string;
            SentTimestamp: string;
            SequenceNumber?: string | undefined;
            MessageDeduplicationId?: string | undefined;
            MessageGroupId?: string | undefined;
            AWSTraceHeader?: string | undefined;
            DeadLetterQueueSourceArn?: string | undefined;
        };
        messageAttributes: Record<string, {
            dataType: string;
            stringValue?: string | undefined;
            binaryValue?: string | undefined;
            stringListValues?: string[] | undefined;
            binaryListValues?: string[] | undefined;
        }>;
        md5OfBody: string;
        md5OfMessageAttributes?: string | null | undefined;
    }, {
        messageId: string;
        body: string;
        eventSource: "aws:sqs";
        awsRegion: string;
        eventSourceARN: string;
        receiptHandle: string;
        attributes: {
            ApproximateReceiveCount: string;
            ApproximateFirstReceiveTimestamp: string;
            SenderId: string;
            SentTimestamp: string;
            SequenceNumber?: string | undefined;
            MessageDeduplicationId?: string | undefined;
            MessageGroupId?: string | undefined;
            AWSTraceHeader?: string | undefined;
            DeadLetterQueueSourceArn?: string | undefined;
        };
        messageAttributes: Record<string, {
            dataType: string;
            stringValue?: string | undefined;
            binaryValue?: string | undefined;
            stringListValues?: string[] | undefined;
            binaryListValues?: string[] | undefined;
        }>;
        md5OfBody: string;
        md5OfMessageAttributes?: string | null | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        messageId: string;
        body: string;
        eventSource: "aws:sqs";
        awsRegion: string;
        eventSourceARN: string;
        receiptHandle: string;
        attributes: {
            ApproximateReceiveCount: string;
            ApproximateFirstReceiveTimestamp: string;
            SenderId: string;
            SentTimestamp: string;
            SequenceNumber?: string | undefined;
            MessageDeduplicationId?: string | undefined;
            MessageGroupId?: string | undefined;
            AWSTraceHeader?: string | undefined;
            DeadLetterQueueSourceArn?: string | undefined;
        };
        messageAttributes: Record<string, {
            dataType: string;
            stringValue?: string | undefined;
            binaryValue?: string | undefined;
            stringListValues?: string[] | undefined;
            binaryListValues?: string[] | undefined;
        }>;
        md5OfBody: string;
        md5OfMessageAttributes?: string | null | undefined;
    }[];
}, {
    Records: {
        messageId: string;
        body: string;
        eventSource: "aws:sqs";
        awsRegion: string;
        eventSourceARN: string;
        receiptHandle: string;
        attributes: {
            ApproximateReceiveCount: string;
            ApproximateFirstReceiveTimestamp: string;
            SenderId: string;
            SentTimestamp: string;
            SequenceNumber?: string | undefined;
            MessageDeduplicationId?: string | undefined;
            MessageGroupId?: string | undefined;
            AWSTraceHeader?: string | undefined;
            DeadLetterQueueSourceArn?: string | undefined;
        };
        messageAttributes: Record<string, {
            dataType: string;
            stringValue?: string | undefined;
            binaryValue?: string | undefined;
            stringListValues?: string[] | undefined;
            binaryListValues?: string[] | undefined;
        }>;
        md5OfBody: string;
        md5OfMessageAttributes?: string | null | undefined;
    }[];
}>;
export { SqsSchema, SqsRecordSchema, SqsAttributesSchema, SqsMsgAttributeSchema, };
//# sourceMappingURL=sqs.d.ts.map